@@ -21,7 +21,7 @@
 // [[Rcpp::depends(RcppArmadillo)]]
 
 
-ProbitMLModelSelection::ProbitMLModelSelection(int iNum_of_iterations, List list_Data, List list_InitialValues, List list_HyperPara, List list_UpdatePara, List list_TuningPara)
+ProbitMLModelSelection::ProbitMLModelSelection(int iNum_of_iterations, List list_Data, bool b_Robustness, List list_InitialValues, List list_HyperPara, List list_UpdatePara, List list_TuningPara)
 {
     //Rcout<< "Read Data 0" << endl;
     Num_of_iterations = iNum_of_iterations;
@@ -30,7 +30,7 @@ ProbitMLModelSelection::ProbitMLModelSelection(int iNum_of_iterations, List list
     HyperPara = list_HyperPara;
     UpdatePara = list_UpdatePara;
     TuningPara = list_TuningPara;
-    
+    Robustness = b_Robustness;
     
     updateystar = as<bool>(UpdatePara["UpdateYstar"]);
     updateb = as<bool>(UpdatePara["UpdateRandomEffect"]);
@@ -82,7 +82,7 @@ ProbitMLModelSelection::ProbitMLModelSelection(int iNum_of_iterations, List list
     b_samples.set_size(Num_of_RanEffs, Num_of_obs, Num_of_iterations);
     b_samples.zeros();
     nu_samples.set_size(Num_of_obs, Num_of_iterations);
-    nu_samples.zeros();
+    nu_samples.ones();
     beta_samples.set_size(Num_of_covariates,Num_of_iterations);
     beta_samples.zeros();
     Sigma_samples.set_size(Num_of_RanEffs, Num_of_RanEffs, Num_of_iterations);
@@ -91,7 +91,7 @@ ProbitMLModelSelection::ProbitMLModelSelection(int iNum_of_iterations, List list
     b_mean.set_size(Num_of_RanEffs, Num_of_obs);
     b_mean.zeros();
     nu_mean.set_size(Num_of_obs);
-    nu_mean.zeros();
+    nu_mean.ones();
     beta_mean.set_size(Num_of_covariates);
     beta_mean.zeros();
     Sigma_mean.set_size(Num_of_RanEffs, Num_of_RanEffs);
@@ -101,7 +101,8 @@ ProbitMLModelSelection::ProbitMLModelSelection(int iNum_of_iterations, List list
     
     b_samples.slice(0) = as<mat>(InitialValues["b"]);
     //Rcout<< "Initial Values nu" << endl;
-    nu_samples.col(0) = as<vec>(InitialValues["nu"]);
+    if(Robustness)
+        nu_samples.col(0) = as<vec>(InitialValues["nu"]);
     //Rcout<< "Initial Values beta" << endl;
     beta_samples.col(0) = as<vec>(InitialValues["beta"]);
     //Rcout<< "Initial Values Sigma" << endl;
@@ -346,7 +347,8 @@ void ProbitMLModelSelection::ParameterEstimation()
     b_mean = mean(b_samples, 2);
     Sigma_mean = mean(Sigma_samples, 2);
     beta_mean = mean(beta_samples, 1);
-    nu_mean = mean(nu_samples, 1);
+    if(Robustness)
+        nu_mean = mean(nu_samples, 1);
     delta_mean = mean(delta_samples, 1);
 
     rowvec X_tmp, Z_tmp, Ri_tmp;
@@ -505,16 +507,24 @@ SEXP ProbitMLModelSelection::MCMC_Procedure()
 
     while(iter < Num_of_iterations-1){
         Update_ystar_b_beta_Sigma(iter);
-        if(updatenu)
+        if(Robustness)
             Update_nu(iter);
-        else
-            nu_samples.col(iter+1) = nu_samples.col(iter);
+        //else
+            //nu_samples.col(iter+1) = nu_samples.col(iter);
         if(updatedelta)
             Update_delta(iter);
 
         percent = (100 *iter) / (Num_of_iterations-2) ;
         iter++;
 
+        
+        if(percent%2==0){
+            Rcout << "\r" <<  "[" << std::string(percent / 2, (char)61) << std::string(100 / 2 - percent / 2, ' ') << "]" << "\t" << percent << "%";
+            //Rcout << percent << "%" << " [Iteration " << iter + 1 << " of " << Num_of_iterations << "]";
+            Rcout.flush();
+        }
+         
+
     }
     Rcout << endl << "Finish MCMC Procedure." << endl;
   
@@ -522,7 +532,8 @@ SEXP ProbitMLModelSelection::MCMC_Procedure()
     
     PosteriorSamples["ystar.samples"] = Y_star_sample;
     PosteriorSamples["b.samples"] = b_samples;
-    PosteriorSamples["nu.samples"] = nu_samples;
+    if(Robustness)
+        PosteriorSamples["nu.samples"] = nu_samples;
     PosteriorSamples["beta.samples"] = beta_samples;
     PosteriorSamples["Sigma.samples"] = Sigma_samples;
     PosteriorSamples["delta.samples"] = delta_samples;
@@ -530,7 +541,9 @@ SEXP ProbitMLModelSelection::MCMC_Procedure()
         PosteriorEstimates["delta.mean"] = delta_mean;
 
     PosteriorEstimates["beta.mean"] = beta_mean;
-    PosteriorEstimates["nu.mean"] = nu_mean;
+    if(Robustness)
+        PosteriorEstimates["nu.mean"] = nu_mean;
+    
     PosteriorEstimates["b.mean"] = b_mean;
     PosteriorEstimates["Sigma.mean"] = Sigma_mean;
 
