@@ -66,14 +66,14 @@ private:
     double acc_rate_delta; 
     
     bool updateystar, updateb, updatenu, updatebeta, updateSigma, updatedelta; //, updateomega;
-    bool Unconstraint;
+    bool Unconstraint, Robustness;
     
     double AIC, BIC, CIC, DIC, MPL, logL, RJ_R, ACC;// MSPE;
     //cube pred_y;
     //vec lower, upper;
     
 public:
-    ProbitMLModelSelection(int iNum_of_iterations, List list_Data, List list_InitialValues, List list_HyperPara, List list_UpdatePara, List list_TuningPara);
+    ProbitMLModelSelection(int iNum_of_iterations, List list_Data, bool bRobustness, List list_InitialValues, List list_HyperPara, List list_UpdatePara, List list_TuningPara);
     
 
     void Update_nu(int iter);
